"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VitePluginNode = void 0;
const _1 = require(".");
const rollup_plugin_swc_1 = require("./rollup-plugin-swc");
const server_1 = require("./server");
function VitePluginNode(cfg) {
    var _a, _b, _c;
    const config = {
        appPath: cfg.appPath,
        adapter: cfg.adapter,
        appName: (_a = cfg.appName) !== null && _a !== void 0 ? _a : 'app',
        tsCompiler: (_b = cfg.tsCompiler) !== null && _b !== void 0 ? _b : 'esbuild',
        exportName: (_c = cfg.exportName) !== null && _c !== void 0 ? _c : 'viteNodeApp'
    };
    const plugins = [
        {
            name: _1.PLUGIN_NAME,
            config: () => ({
                build: {
                    ssr: config.appPath
                },
                server: {
                    hmr: false
                },
                esbuild: config.tsCompiler === 'esbuild' ? {} : false,
                VitePluginNodeConfig: config
            }),
            configureServer: (server) => {
                server.middlewares.use((0, server_1.createMiddleware)(server));
            }
        }
    ];
    if (config.tsCompiler === 'swc') {
        plugins.push({
            ...(0, rollup_plugin_swc_1.RollupPluginSwc)({
                jsc: {
                    target: 'es2019',
                    parser: {
                        syntax: 'typescript',
                        decorators: true
                    },
                    transform: {
                        legacyDecorator: true,
                        decoratorMetadata: true
                    }
                }
            })
        });
    }
    return plugins;
}
exports.VitePluginNode = VitePluginNode;
//# sourceMappingURL=vite-plugin-node.js.map